@@ -310,7 +310,7 @@ example:
 find znodes whose path matches a given text (regardless of the latter's case).
 
 example:
-  find / fOO
+  ifind / fOO
   /foo2
   /FOOish/wayland
   /fooish/xorg
@@ -330,6 +330,61 @@ example:
 
             self._full_match(full_path, match, check, flags)
 
+    @connected
+    @ensure_params([("path", True), ("content", True), ("show_matches", False)])
+    @check_path_exists
+    def do_grep(self, params):
+        show_matches = params.show_matches.lower() == "true"
+        self._full_grep(params.path, params.content, show_matches, 0)
+
+    def complete_grep(self, cmd_param_text, full_cmd, start_idx, end_idx):
+        return self._complete_path(cmd_param_text, full_cmd)
+
+    def help_grep(self):
+        print("""
+find znodes whose value matches a given text.
+
+example:
+  grep / unbound true
+  /passwd: unbound:x:992:991:Unbound DNS resolver:/etc/unbound:/sbin/nologin
+  /copy/passwd: unbound:x:992:991:Unbound DNS resolver:/etc/unbound:/sbin/nologin
+""")
+
+    @connected
+    @ensure_params([("path", True), ("content", True), ("show_matches", False)])
+    @check_path_exists
+    def do_igrep(self, params):
+        show_matches = params.show_matches.lower() == "true"
+        self._full_grep(params.path, params.content, show_matches, re.IGNORECASE)
+
+    def complete_igrep(self, cmd_param_text, full_cmd, start_idx, end_idx):
+        return self._complete_path(cmd_param_text, full_cmd)
+
+    def help_igrep(self):
+        print("""
+find znodes whose value matches a given text (case-insensite).
+
+example:
+  igrep / UNBound true
+  /passwd: unbound:x:992:991:Unbound DNS resolver:/etc/unbound:/sbin/nologin
+  /copy/passwd: unbound:x:992:991:Unbound DNS resolver:/etc/unbound:/sbin/nologin
+""")
+
+    def _full_grep(self, path, content, show_matches, flags):
+        for c in self._zk.get_children(path):
+            full_path = os.path.join(path, c)
+            value, _ = self._zk.get(full_path)
+
+            if show_matches:
+                for line in value.split("\n"):
+                    if re.search(content, line, flags):
+                        print("%s: %s" % (full_path, line))
+            else:
+                if re.search(content, value, flags):
+                    print(full_path)
+
+            self._full_grep(full_path, content, show_matches, flags)
+
     @connected
     @ensure_params([("path", True)])
     @check_path_exists
